==> qmmp-1.1.7.tar.bz2: qmmp-1.1.7/src/plugins/Input/flac/translations/flac_plugin_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="58"/>
        <source>FLAC Plugin</source>
        <translation>Πρόσθετο FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="60"/>
        <source>FLAC Files</source>
        <translation>Αρχεία FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="191"/>
        <source>About FLAC Audio Plugin</source>
        <translation>Σχετικά με το πρόσθετο ήχου FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="192"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Qmmp πρόσθετο ήχου FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="193"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Γράφτηκε από τον: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="89"/>
        <source>Length</source>
        <translation>Διάρκεια</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="90"/>
        <source>Sample rate</source>
        <translation>Ρυθμός δειγματοληψίας</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="90"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="91"/>
        <source>Channels</source>
        <translation>Κανάλια</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="92"/>
        <source>Bitrate</source>
        <translation>Ρυθμός bit</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="92"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="93"/>
        <source>File size</source>
        <translation>Μέγεθος αρχείου</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="93"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Input/flac/translations/flac_plugin_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="53"/>
        <source>FLAC Plugin</source>
        <translation>Πρόσθετο FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="55"/>
        <source>FLAC Files</source>
        <translation>Αρχεία FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="186"/>
        <source>About FLAC Audio Plugin</source>
        <translation>Σχετικά με το πρόσθετο ήχου FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="187"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Qmmp πρόσθετο ήχου FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="188"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Γράφτηκε από τον: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="89"/>
        <source>Length</source>
        <translation>Διάρκεια</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="90"/>
        <source>Sample rate</source>
        <translation>Ρυθμός δειγματοληψίας</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="90"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="91"/>
        <source>Channels</source>
        <translation>Κανάλια</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="92"/>
        <source>Bitrate</source>
        <translation>Ρυθμός bit</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="92"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="93"/>
        <source>File size</source>
        <translation>Μέγεθος αρχείου</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="93"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
